@@ -14,6 +14,11 @@ import org.gnu.glib.Type;
  * polygon on a GnomeCanvas.
  */
 public class CanvasPolygon extends CanvasShape {
+
+	public CanvasPolygon(CanvasGroup group) {
+		super(group, gnome_canvas_polygon_get_type());
+	}
+
 	/**
 	 * Constructs an instance of CanvasPolygon from a native widget resource.
 	 * @param handle The handle to the native widget.
@@ -22,9 +27,6 @@ public class CanvasPolygon extends CanvasShape {
 		super(handle);
 	}
 
-	protected void noopInit() {
-	}
-
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
