@@ -13,18 +13,16 @@ import java.util.Vector;
 
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
-import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.ColorPickerEvent;
 import org.gnu.gnome.event.ColorPickerListener;
 import org.gnu.gtk.Button;
-
 /**
- * The ColorPicker button pops up a ColorSelectionDialog and allows a color to
- * be selected. The button changes color to match the currently selected color.
- * The colors can be set using doubles - values between 0.0 and 1.0, 8 bit
- * integers - values between 0 and 255, and 16 bit integers - values between 0
- * and 65535.
+ * The ColorPicker button pops up a ColorSelectionDialog and
+ * allows a color to be selected. The button changes color to match the
+ * currently selected color. The colors can be set using doubles -
+ * values between 0.0 and 1.0, 8 bit integers - values between 0 and
+ * 255, and 16 bit integers - values between 0 and 65535.
  * 
  * @deprecated
  */
@@ -44,13 +42,12 @@ public class ColorPicker extends Button {
 	/**
 	 * Construct a ColorPicker using a handle to a native resource.
 	 */
-	public ColorPicker(Handle handle) {
+	public ColorPicker(int handle) {
 		super(handle);
 	}
 
 	/**
 	 * Get the alpha of the color as a double value between 0.0 and 1.0.
-	 * 
 	 * @return The alpha of the color.
 	 */
 	public double getAlphaDouble() {
@@ -66,7 +63,6 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Get the blue element of the color as a double value between 0.0 and 1.0.
-	 * 
 	 * @return The blue element of the color.
 	 */
 	public double getBlueDouble() {
@@ -81,8 +77,8 @@ public class ColorPicker extends Button {
 	}
 
 	/**
-	 * Get the green element of the color as a double value between 0.0 and 1.0.
-	 * 
+	 * Get the green element of the color as a double value between 0.0 and
+	 * 1.0.
 	 * @return The green element of the color.
 	 */
 	public double getGreenDouble() {
@@ -98,7 +94,6 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Get the red element of the color as a double value between 0.0 and 1.0.
-	 * 
 	 * @return The red element of the color.
 	 */
 	public double getRedDouble() {
@@ -114,7 +109,6 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Get the alpha of the color as a 8 bit value between 0 and 255.
-	 * 
 	 * @return The alpha of the color.
 	 */
 	public int getAlpha8Bit() {
@@ -130,7 +124,6 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Get the blue element of the color as a 8 bit value between 0 and 255.
-	 * 
 	 * @return The blue element of the color.
 	 */
 	public int getBlue8Bit() {
@@ -146,7 +139,6 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Get the green element of the color as a double value between 0 and 255.
-	 * 
 	 * @return The green element of the color.
 	 */
 	public int getGreen8Bit() {
@@ -162,7 +154,6 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Get the red element of the color as a double value between 0 and 255.
-	 * 
 	 * @return The red element of the color.
 	 */
 	public int getRed8Bit() {
@@ -178,7 +169,6 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Get the alpha of the color as a 16 bit value between 0 and 65535.
-	 * 
 	 * @return The alpha of the color.
 	 */
 	public int getAlpha16Bit() {
@@ -194,7 +184,6 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Get the blue element of the color as a 16 bit value between 0 and 65535.
-	 * 
 	 * @return The blue element of the color.
 	 */
 	public int getBlue16Bit() {
@@ -209,8 +198,8 @@ public class ColorPicker extends Button {
 	}
 
 	/**
-	 * Get the green element of the color as a double value between 0 and 65535.
-	 * 
+	 * Get the green element of the color as a double value between 0 and
+	 * 65535.
 	 * @return The green element of the color.
 	 */
 	public int getGreen16Bit() {
@@ -226,7 +215,6 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Get the red element of the color as a double value between 0 and 65535.
-	 * 
 	 * @return The red element of the color.
 	 */
 	public int getRed16Bit() {
@@ -242,8 +230,7 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Returns whether ColorPicker uses alpha.
-	 * 
-	 * @return True if alpha is used. Otherwise, false.
+	 * @return True if alpha is used.  Otherwise, false.
 	 */
 	public boolean getAlphaEnabled() {
 		return gnome_color_picker_get_use_alpha(getHandle());
@@ -251,8 +238,7 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Returns whether ColorPicker uses dither.
-	 * 
-	 * @return True if dither is used. Otherwise, false.
+	 * @return True if dither is used.  Otherwise, false.
 	 */
 	public boolean getDitherEnabled() {
 		return gnome_color_picker_get_dither(getHandle());
@@ -260,7 +246,6 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Gets the title of the color picker.
-	 * 
 	 * @return The title for the color picker.
 	 */
 	public String getTitle() {
@@ -268,41 +253,28 @@ public class ColorPicker extends Button {
 	}
 
 	/**
-	 * A shortcut method to set all the color values with one call. All values
+	 * A shortcut method to set all the color values with one call.  All values
 	 * must be a double value between 0.0 and 1.0.
-	 * 
-	 * @param alpha
-	 *            The alpha of the color.
-	 * @param blue
-	 *            The blue element of the color.
-	 * @param green
-	 *            The green element of the color.
-	 * @param red
-	 *            The red element of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if any given value is outside of the valid range
-	 *                0.0 to 1.0.
+	 * @param alpha The alpha of the color.
+	 * @param blue The blue element of the color.
+	 * @param green The green element of the color.
+	 * @param red The red element of the color.
+	 * @exception IllegalArgumentException Thrown if any given value is outside
+	 *                                     of the valid range 0.0 to 1.0.
 	 */
-	public void setColorDouble(double alpha, double blue, double green,
-			double red) throws IllegalArgumentException {
+	public void setColorDouble(double alpha, double blue, double green, double red) throws IllegalArgumentException {
 		if (alpha < 0.0 || alpha > 1.0) {
 			throw new IllegalArgumentException(
-					"The value "
-							+ alpha
-							+ " is outside the acceptable range of 0.0 to 1.0 for alpha.");
+				"The value " + alpha + " is outside the acceptable range of 0.0 to 1.0 for alpha.");
 		} else if (blue < 0.0 || blue > 1.0) {
 			throw new IllegalArgumentException(
-					"The value "
-							+ blue
-							+ " is outside the acceptable range of 0.0 to 1.0 for blue.");
+				"The value " + blue + " is outside the acceptable range of 0.0 to 1.0 for blue.");
 		} else if (green < 0.0 || green > 1.0) {
 			throw new IllegalArgumentException(
-					"The value "
-							+ green
-							+ " is outside the acceptable range of 0.0 to 1.0 for green.");
+				"The value " + green + " is outside the acceptable range of 0.0 to 1.0 for green.");
 		} else if (red < 0.0 || red > 1.0) {
-			throw new IllegalArgumentException("The value " + red
-					+ " is outside the acceptable range of 0.0 to 1.0 for red.");
+			throw new IllegalArgumentException(
+				"The value " + red + " is outside the acceptable range of 0.0 to 1.0 for red.");
 		}
 
 		gnome_color_picker_set_d(getHandle(), red, green, blue, alpha);
@@ -310,16 +282,14 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Set the alpha of the color as a double value between 0.0 and 1.0.
-	 * 
-	 * @param alpha
-	 *            The alpha of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if alpha is outside of the valid range 0.0 to 1.0.
+	 * @param alpha The alpha of the color.
+	 * @exception IllegalArgumentException Thrown if alpha is outside of the
+	 *                                     valid range 0.0 to 1.0.
 	 */
 	public void setAlphaDouble(double alpha) throws IllegalArgumentException {
 		if (alpha < 0.0 || alpha > 1.0) {
-			throw new IllegalArgumentException("The value " + alpha
-					+ " is outside the acceptable range of 0.0 to 1.0.");
+			throw new IllegalArgumentException(
+				"The value " + alpha + " is outside the acceptable range of 0.0 to 1.0.");
 		}
 
 		double a[] = new double[1];
@@ -334,16 +304,14 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Set the blue element of the color as a double value between 0.0 and 1.0.
-	 * 
-	 * @param color
-	 *            The blue element of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if color is outside of the valid range 0.0 to 1.0.
+	 * @param color The blue element of the color.
+	 * @exception IllegalArgumentException Thrown if color is outside of the
+	 *                                     valid range 0.0 to 1.0.
 	 */
 	public void setBlueDouble(double color) throws IllegalArgumentException {
 		if (color < 0.0 || color > 1.0) {
-			throw new IllegalArgumentException("The value " + color
-					+ " is outside the acceptable range of 0.0 to 1.0.");
+			throw new IllegalArgumentException(
+				"The value " + color + " is outside the acceptable range of 0.0 to 1.0.");
 		}
 
 		double alpha[] = new double[1];
@@ -353,22 +321,20 @@ public class ColorPicker extends Button {
 
 		gnome_color_picker_get_d(getHandle(), red, green, blue, alpha);
 		blue[0] = color;
-		gnome_color_picker_set_d(getHandle(), red[0], green[0], blue[0],
-				alpha[0]);
+		gnome_color_picker_set_d(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
-	 * Set the green element of the color as a double value between 0.0 and 1.0.
-	 * 
-	 * @param color
-	 *            The green element of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if color is outside of the valid range 0.0 to 1.0.
+	 * Set the green element of the color as a double value between 0.0 and
+	 * 1.0.
+	 * @param color The green element of the color.
+	 * @exception IllegalArgumentException Thrown if color is outside of the
+	 *                                     valid range 0.0 to 1.0.
 	 */
 	public void setGreenDouble(double color) throws IllegalArgumentException {
 		if (color < 0.0 || color > 1.0) {
-			throw new IllegalArgumentException("The value " + color
-					+ " is outside the acceptable range of 0.0 to 1.0.");
+			throw new IllegalArgumentException(
+				"The value " + color + " is outside the acceptable range of 0.0 to 1.0.");
 		}
 
 		double alpha[] = new double[1];
@@ -378,22 +344,19 @@ public class ColorPicker extends Button {
 
 		gnome_color_picker_get_d(getHandle(), red, green, blue, alpha);
 		green[0] = color;
-		gnome_color_picker_set_d(getHandle(), red[0], green[0], blue[0],
-				alpha[0]);
+		gnome_color_picker_set_d(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
 	 * Set the red element of the color as a double value between 0.0 and 1.0.
-	 * 
-	 * @param color
-	 *            The red element of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if color is outside of the valid range 0.0 to 1.0.
+	 * @param color The red element of the color.
+	 * @exception IllegalArgumentException Thrown if color is outside of the
+	 *                                     valid range 0.0 to 1.0.
 	 */
 	public void setRedDouble(double color) throws IllegalArgumentException {
 		if (color < 0.0 || color > 1.0) {
-			throw new IllegalArgumentException("The value " + color
-					+ " is outside the acceptable range of 0.0 to 1.0.");
+			throw new IllegalArgumentException(
+				"The value " + color + " is outside the acceptable range of 0.0 to 1.0.");
 		}
 
 		double alpha[] = new double[1];
@@ -403,40 +366,32 @@ public class ColorPicker extends Button {
 
 		gnome_color_picker_get_d(getHandle(), red, green, blue, alpha);
 		red[0] = color;
-		gnome_color_picker_set_d(getHandle(), red[0], green[0], blue[0],
-				alpha[0]);
+		gnome_color_picker_set_d(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
-	 * A shortcut method to set all the color values with one call. All values
+	 * A shortcut method to set all the color values with one call.  All values
 	 * must be a integer value between 0 and 255.
-	 * 
-	 * @param alpha
-	 *            The alpha of the color.
-	 * @param blue
-	 *            The blue element of the color.
-	 * @param green
-	 *            The green element of the color.
-	 * @param red
-	 *            The red element of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if any given value is outside of the valid range 0
-	 *                to 255.
+	 * @param alpha The alpha of the color.
+	 * @param blue The blue element of the color.
+	 * @param green The green element of the color.
+	 * @param red The red element of the color.
+	 * @exception IllegalArgumentException Thrown if any given value is outside
+	 *                                     of the valid range 0 to 255.
 	 */
-	public void setColor8Bit(int alpha, int blue, int green, int red)
-			throws IllegalArgumentException {
+	public void setColor8Bit(int alpha, int blue, int green, int red) throws IllegalArgumentException {
 		if (alpha < 0 || alpha > 255) {
-			throw new IllegalArgumentException("The value " + alpha
-					+ " is outside the acceptable range of 0 to 255 for alpha.");
+			throw new IllegalArgumentException(
+				"The value " + alpha + " is outside the acceptable range of 0 to 255 for alpha.");
 		} else if (blue < 0 || blue > 255) {
-			throw new IllegalArgumentException("The value " + blue
-					+ " is outside the acceptable range of 0 to 255 for blue.");
+			throw new IllegalArgumentException(
+				"The value " + blue + " is outside the acceptable range of 0 to 255 for blue.");
 		} else if (green < 0 || green > 255) {
-			throw new IllegalArgumentException("The value " + green
-					+ " is outside the acceptable range of 0 to 255 for green.");
+			throw new IllegalArgumentException(
+				"The value " + green + " is outside the acceptable range of 0 to 255 for green.");
 		} else if (red < 0 || red > 255) {
-			throw new IllegalArgumentException("The value " + red
-					+ " is outside the acceptable range of 0 to 255 for red.");
+			throw new IllegalArgumentException(
+				"The value " + red + " is outside the acceptable range of 0 to 255 for red.");
 		}
 
 		gnome_color_picker_set_i8(getHandle(), red, green, blue, alpha);
@@ -444,16 +399,13 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Set the alpha of the color as a 8 bit value between 0 and 255.
-	 * 
-	 * @param alpha
-	 *            The alpha of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if alpha is outside of the valid range 0 to 255.
+	 * @param alpha The alpha of the color.
+	 * @exception IllegalArgumentException Thrown if alpha is outside of the
+	 *                                     valid range 0 to 255.
 	 */
 	public void setAlpha8Bit(int alpha) throws IllegalArgumentException {
 		if (alpha < 0 || alpha > 255) {
-			throw new IllegalArgumentException("The value " + alpha
-					+ " is outside the acceptable range of 0 to 255.");
+			throw new IllegalArgumentException("The value " + alpha + " is outside the acceptable range of 0 to 255.");
 		}
 
 		int a[] = new int[1];
@@ -468,16 +420,13 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Set the blue element of the color as a 8 bit value between 0 and 255.
-	 * 
-	 * @param color
-	 *            The blue element of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if color is outside of the valid range 0 to 255.
+	 * @param color The blue element of the color.
+	 * @exception IllegalArgumentException Thrown if color is outside of the
+	 *                                     valid range 0 to 255.
 	 */
 	public void setBlue8Bit(int color) throws IllegalArgumentException {
 		if (color < 0 || color > 255) {
-			throw new IllegalArgumentException("The value " + color
-					+ " is outside the acceptable range of 0 to 255.");
+			throw new IllegalArgumentException("The value " + color + " is outside the acceptable range of 0 to 255.");
 		}
 
 		int alpha[] = new int[1];
@@ -487,22 +436,18 @@ public class ColorPicker extends Button {
 
 		gnome_color_picker_get_i8(getHandle(), red, green, blue, alpha);
 		blue[0] = color;
-		gnome_color_picker_set_i8(getHandle(), red[0], green[0], blue[0],
-				alpha[0]);
+		gnome_color_picker_set_i8(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
 	 * Set the green element of the color as a integer value between 0 and 255.
-	 * 
-	 * @param color
-	 *            The green element of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if color is outside of the valid range 0 to 255.
+	 * @param color The green element of the color.
+	 * @exception IllegalArgumentException Thrown if color is outside of the
+	 *                                     valid range 0 to 255.
 	 */
 	public void setGreen8Bit(int color) throws IllegalArgumentException {
 		if (color < 0 || color > 255) {
-			throw new IllegalArgumentException("The value " + color
-					+ " is outside the acceptable range of 0 to 255.");
+			throw new IllegalArgumentException("The value " + color + " is outside the acceptable range of 0 to 255.");
 		}
 
 		int alpha[] = new int[1];
@@ -512,22 +457,18 @@ public class ColorPicker extends Button {
 
 		gnome_color_picker_get_i8(getHandle(), red, green, blue, alpha);
 		green[0] = color;
-		gnome_color_picker_set_i8(getHandle(), red[0], green[0], blue[0],
-				alpha[0]);
+		gnome_color_picker_set_i8(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
 	 * Set the red element of the color as a integer value between 0 and 255.
-	 * 
-	 * @param color
-	 *            The red element of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if color is outside of the valid range 0 to 255.
+	 * @param color The red element of the color.
+	 * @exception IllegalArgumentException Thrown if color is outside of the
+	 *                                     valid range 0 to 255.
 	 */
 	public void setRed8Bit(int color) throws IllegalArgumentException {
 		if (color < 0 || color > 255) {
-			throw new IllegalArgumentException("The value " + color
-					+ " is outside the acceptable range of 0 to 255.");
+			throw new IllegalArgumentException("The value " + color + " is outside the acceptable range of 0 to 255.");
 		}
 
 		int alpha[] = new int[1];
@@ -537,46 +478,32 @@ public class ColorPicker extends Button {
 
 		gnome_color_picker_get_i8(getHandle(), red, green, blue, alpha);
 		red[0] = color;
-		gnome_color_picker_set_i8(getHandle(), red[0], green[0], blue[0],
-				alpha[0]);
+		gnome_color_picker_set_i8(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
-	 * A shortcut method to set all the color values with one call. All values
+	 * A shortcut method to set all the color values with one call.  All values
 	 * must be a integer value between 0 and 65535.
-	 * 
-	 * @param alpha
-	 *            The alpha of the color.
-	 * @param blue
-	 *            The blue element of the color.
-	 * @param green
-	 *            The green element of the color.
-	 * @param red
-	 *            The red element of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if any given value is outside of the valid range 0
-	 *                to 65535.
+	 * @param alpha The alpha of the color.
+	 * @param blue The blue element of the color.
+	 * @param green The green element of the color.
+	 * @param red The red element of the color.
+	 * @exception IllegalArgumentException Thrown if any given value is outside
+	 *                                     of the valid range 0 to 65535.
 	 */
-	public void setColor16Bit(int alpha, int blue, int green, int red)
-			throws IllegalArgumentException {
+	public void setColor16Bit(int alpha, int blue, int green, int red) throws IllegalArgumentException {
 		if (alpha < 0 || alpha > 65535) {
 			throw new IllegalArgumentException(
-					"The value "
-							+ alpha
-							+ " is outside the acceptable range of 0 to 65535 for alpha.");
+				"The value " + alpha + " is outside the acceptable range of 0 to 65535 for alpha.");
 		} else if (blue < 0 || blue > 65535) {
 			throw new IllegalArgumentException(
-					"The value "
-							+ blue
-							+ " is outside the acceptable range of 0 to 65535 for blue.");
+				"The value " + blue + " is outside the acceptable range of 0 to 65535 for blue.");
 		} else if (green < 0 || green > 65535) {
 			throw new IllegalArgumentException(
-					"The value "
-							+ green
-							+ " is outside the acceptable range of 0 to 65535 for green.");
+				"The value " + green + " is outside the acceptable range of 0 to 65535 for green.");
 		} else if (red < 0 || red > 65535) {
-			throw new IllegalArgumentException("The value " + red
-					+ " is outside the acceptable range of 0 to 65535 for red.");
+			throw new IllegalArgumentException(
+				"The value " + red + " is outside the acceptable range of 0 to 65535 for red.");
 		}
 
 		gnome_color_picker_set_i8(getHandle(), red, green, blue, alpha);
@@ -584,16 +511,14 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Set the alpha of the color as a 16 bit value between 0 and 65535.
-	 * 
-	 * @param alpha
-	 *            The alpha of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if alpha is outside of the valid range 0 to 65535.
+	 * @param alpha The alpha of the color.
+	 * @exception IllegalArgumentException Thrown if alpha is outside of the
+	 *                                     valid range 0 to 65535.
 	 */
 	public void setAlpha16Bit(int alpha) throws IllegalArgumentException {
 		if (alpha < 0 || alpha > 65535) {
-			throw new IllegalArgumentException("The value " + alpha
-					+ " is outside the acceptable range of 0 to 65535.");
+			throw new IllegalArgumentException(
+				"The value " + alpha + " is outside the acceptable range of 0 to 65535.");
 		}
 
 		int a[] = new int[1];
@@ -608,16 +533,14 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Set the blue element of the color as a 16 bit value between 0 and 65535.
-	 * 
-	 * @param color
-	 *            The blue element of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if color is outside of the valid range 0 to 65535.
+	 * @param color The blue element of the color.
+	 * @exception IllegalArgumentException Thrown if color is outside of the
+	 *                                     valid range 0 to 65535.
 	 */
 	public void setBlue16Bit(int color) throws IllegalArgumentException {
 		if (color < 0 || color > 65535) {
-			throw new IllegalArgumentException("The value " + color
-					+ " is outside the acceptable range of 0 to 65535.");
+			throw new IllegalArgumentException(
+				"The value " + color + " is outside the acceptable range of 0 to 65535.");
 		}
 
 		int alpha[] = new int[1];
@@ -627,23 +550,20 @@ public class ColorPicker extends Button {
 
 		gnome_color_picker_get_i16(getHandle(), red, green, blue, alpha);
 		blue[0] = color;
-		gnome_color_picker_set_i16(getHandle(), red[0], green[0], blue[0],
-				alpha[0]);
+		gnome_color_picker_set_i16(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
 	 * Set the green element of the color as a integer value between 0 and
 	 * 65535.
-	 * 
-	 * @param color
-	 *            The green element of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if color is outside of the valid range 0 to 65535.
+	 * @param color The green element of the color.
+	 * @exception IllegalArgumentException Thrown if color is outside of the
+	 *                                     valid range 0 to 65535.
 	 */
 	public void setGreen16Bit(int color) throws IllegalArgumentException {
 		if (color < 0 || color > 65535) {
-			throw new IllegalArgumentException("The value " + color
-					+ " is outside the acceptable range of 0 to 65535.");
+			throw new IllegalArgumentException(
+				"The value " + color + " is outside the acceptable range of 0 to 65535.");
 		}
 
 		int alpha[] = new int[1];
@@ -653,22 +573,19 @@ public class ColorPicker extends Button {
 
 		gnome_color_picker_get_i16(getHandle(), red, green, blue, alpha);
 		green[0] = color;
-		gnome_color_picker_set_i16(getHandle(), red[0], green[0], blue[0],
-				alpha[0]);
+		gnome_color_picker_set_i16(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
 	 * Set the red element of the color as a integer value between 0 and 65535.
-	 * 
-	 * @param color
-	 *            The red element of the color.
-	 * @exception IllegalArgumentException
-	 *                Thrown if color is outside of the valid range 0 to 65535.
+	 * @param color The red element of the color.
+	 * @exception IllegalArgumentException Thrown if color is outside of the
+	 *                                     valid range 0 to 65535.
 	 */
 	public void setRed16Bit(int color) throws IllegalArgumentException {
 		if (color < 0 || color > 65535) {
-			throw new IllegalArgumentException("The value " + color
-					+ " is outside the acceptable range of 0 to 65535.");
+			throw new IllegalArgumentException(
+				"The value " + color + " is outside the acceptable range of 0 to 65535.");
 		}
 
 		int alpha[] = new int[1];
@@ -678,14 +595,12 @@ public class ColorPicker extends Button {
 
 		gnome_color_picker_get_i16(getHandle(), red, green, blue, alpha);
 		red[0] = color;
-		gnome_color_picker_set_i16(getHandle(), red[0], green[0], blue[0],
-				alpha[0]);
+		gnome_color_picker_set_i16(getHandle(), red[0], green[0], blue[0], alpha[0]);
 	}
 
 	/**
 	 * Sets whether ColorPicker is to use alpha.
-	 * 
-	 * @param enable True to use alpha. Otherwise, false.
+	 * @param enabled True to use alpha.  Otherwise, false.
 	 */
 	public void setAlphaEnabled(boolean enable) {
 		gnome_color_picker_set_use_alpha(getHandle(), enable);
@@ -693,9 +608,7 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Sets whether ColorPicker is to use dither.
-	 * 
-	 * @param enable
-	 *            True to use dither. Otherwise, false.
+	 * @param enable True to use dither.  Otherwise, false.
 	 */
 	public void setDitherEnabled(boolean enable) {
 		gnome_color_picker_set_dither(getHandle(), enable);
@@ -703,9 +616,7 @@ public class ColorPicker extends Button {
 
 	/**
 	 * Sets the title of the color picker.
-	 * 
-	 * @param title
-	 *            The title for the color picker.
+	 * @param title The title for the color picker.
 	 */
 	public void setTitle(String title) {
 		gnome_color_picker_set_title(getHandle(), title);
@@ -718,12 +629,11 @@ public class ColorPicker extends Button {
 		return new Type(gnome_color_picker_get_type());
 	}
 
-	// ////////////////////////////////////////////////////
+	//////////////////////////////////////////////////////
 	// Event handling
-	// ////////////////////////////////////////////////////
+	//////////////////////////////////////////////////////
 	/**
 	 * Register an object to handle ColorPicker events.
-	 * 
 	 * @see org.gnu.gnome.event.ColorPickerListener
 	 */
 	public void addListener(ColorPickerListener listener) {
@@ -737,10 +647,8 @@ public class ColorPicker extends Button {
 			colorPickerListeners.addElement(listener);
 		}
 	}
-
 	/**
 	 * Removes a listener
-	 * 
 	 * @see #addListener(ColorPickerListener)
 	 */
 	public void removeListener(ColorPickerListener listener) {
@@ -761,8 +669,7 @@ public class ColorPicker extends Button {
 		int size = colorPickerListeners.size();
 		int i = 0;
 		while (i < size) {
-			ColorPickerListener cpl = (ColorPickerListener) colorPickerListeners
-					.elementAt(i);
+			ColorPickerListener cpl = (ColorPickerListener)colorPickerListeners.elementAt(i);
 			cpl.colorPickerEvent(event);
 			i++;
 		}
@@ -774,15 +681,13 @@ public class ColorPicker extends Button {
 
 	public Class getEventListenerClass(String signal) {
 		Class cls = evtMap.getEventListenerClass(signal);
-		if (cls == null)
-			cls = super.getEventListenerClass(signal);
+		if (cls == null) cls = super.getEventListenerClass(signal);
 		return cls;
 	}
 
 	public EventType getEventType(String signal) {
 		EventType et = evtMap.getEventType(signal);
-		if (et == null)
-			et = super.getEventType(signal);
+		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
 
@@ -792,38 +697,51 @@ public class ColorPicker extends Button {
 	}
 
 	/**
-	 * Implementation method to build an EventMap for this widget class. Not
-	 * useful (or supported) for application use.
-	 */
+	* Implementation method to build an EventMap for this widget class.
+	* Not useful (or supported) for application use.
+	*/
 	private static void addEvents(EventMap anEvtMap) {
-		anEvtMap.addEvent("color_set", "handleColorSet",
-				ColorPickerEvent.Type.COLOR_SET, ColorPickerListener.class);
+		anEvtMap.addEvent("color_set", "handleColorSet", ColorPickerEvent.Type.COLOR_SET, ColorPickerListener.class);
 	}
 
+	/****************************************
+	 * BEGINNING OF GENERATED CODE
+	 ****************************************/
 	native static final protected int gnome_color_picker_get_type();
-	native static final protected Handle gnome_color_picker_new();
-	native static final protected void gnome_color_picker_set_d(Handle cp,
-			double red, double green, double blue, double alpha);
-	native static final protected void gnome_color_picker_get_d(Handle cp,
-			double[] red, double[] green, double[] blue, double[] alpha);
-	native static final protected void gnome_color_picker_set_i8(Handle cp,
-			int red, int green, int blue, int alpha);
-	native static final protected void gnome_color_picker_get_i8(Handle cp,
-			int[] red, int[] green, int[] blue, int[] alpha);
-	native static final protected void gnome_color_picker_set_i16(Handle cp,
-			int red, int green, int blue, int alpha);
-	native static final protected void gnome_color_picker_get_i16(Handle cp,
-			int[] red, int[] green, int[] blue, int[] alpha);
-	native static final protected void gnome_color_picker_set_dither(Handle cp,
-			boolean dither);
-	native static final protected boolean gnome_color_picker_get_dither(
-			Handle cp);
-	native static final protected void gnome_color_picker_set_use_alpha(
-			Handle cp, boolean useAlpha);
-	native static final protected boolean gnome_color_picker_get_use_alpha(
-			Handle cp);
-	native static final protected void gnome_color_picker_set_title(Handle cp,
-			String title);
-	native static final protected String gnome_color_picker_get_title(Handle cp);
-
+	native static final protected int gnome_color_picker_new();
+	native static final protected void gnome_color_picker_set_d(
+		int cp,
+		double red,
+		double green,
+		double blue,
+		double alpha);
+	native static final protected void gnome_color_picker_get_d(
+		int cp,
+		double[] red,
+		double[] green,
+		double[] blue,
+		double[] alpha);
+	native static final protected void gnome_color_picker_set_i8(int cp, int red, int green, int blue, int alpha);
+	native static final protected void gnome_color_picker_get_i8(
+		int cp,
+		int[] red,
+		int[] green,
+		int[] blue,
+		int[] alpha);
+	native static final protected void gnome_color_picker_set_i16(int cp, int red, int green, int blue, int alpha);
+	native static final protected void gnome_color_picker_get_i16(
+		int cp,
+		int[] red,
+		int[] green,
+		int[] blue,
+		int[] alpha);
+	native static final protected void gnome_color_picker_set_dither(int cp, boolean dither);
+	native static final protected boolean gnome_color_picker_get_dither(int cp);
+	native static final protected void gnome_color_picker_set_use_alpha(int cp, boolean useAlpha);
+	native static final protected boolean gnome_color_picker_get_use_alpha(int cp);
+	native static final protected void gnome_color_picker_set_title(int cp, String title);
+	native static final protected String gnome_color_picker_get_title(int cp);
+	/****************************************
+	 * END OF GENERATED CODE
+	 ****************************************/
 }
