@@ -13,11 +13,11 @@ import java.util.Date;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.DateEditEvent;
 import org.gnu.gnome.event.DateEditListener;
 import org.gnu.gtk.HBox;
-import org.gnu.gtk.event.GtkEventType;
 
 /**
  * A control which allows the user to select a date.
@@ -207,8 +207,8 @@ public class DateEdit extends HBox {
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
